pub type CodexAppsToolsCache = ConnectorRuntimeManager<ToolInfo>;Expand description
Backward-compatible name for the shared Codex Apps tools runtime.
Aliased Type
pub struct CodexAppsToolsCache { /* private fields */ }pub type CodexAppsToolsCache = ConnectorRuntimeManager<ToolInfo>;Backward-compatible name for the shared Codex Apps tools runtime.
pub struct CodexAppsToolsCache { /* private fields */ }